pub enum Config {
Show 17 variants
Install(InstallConfig),
Download(DownloadConfig),
ListStream(ListStreamConfig),
IsoEmbed(IsoIgnitionEmbedConfig),
IsoShow(IsoIgnitionShowConfig),
IsoRemove(IsoIgnitionRemoveConfig),
IsoIgnitionEmbed(IsoIgnitionEmbedConfig),
IsoIgnitionShow(IsoIgnitionShowConfig),
IsoIgnitionRemove(IsoIgnitionRemoveConfig),
IsoKargsModify(IsoKargsModifyConfig),
IsoKargsReset(IsoKargsResetConfig),
IsoKargsShow(IsoKargsShowConfig),
OsmetFiemap(OsmetFiemapConfig),
OsmetPack(OsmetPackConfig),
OsmetUnpack(OsmetUnpackConfig),
PxeIgnitionWrap(PxeIgnitionWrapConfig),
PxeIgnitionUnwrap(PxeIgnitionUnwrapConfig),
}Tuple Fields of ListStream
Tuple Fields of IsoRemove
Tuple Fields of IsoIgnitionEmbed
Tuple Fields of IsoIgnitionShow
Tuple Fields of IsoIgnitionRemove
Tuple Fields of IsoKargsModify
Tuple Fields of IsoKargsReset
Tuple Fields of IsoKargsShow
Tuple Fields of OsmetFiemap
Tuple Fields of OsmetPack
Tuple Fields of OsmetUnpack
Tuple Fields of PxeIgnitionWrap
Tuple Fields of PxeIgnitionUnwrap
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,