Module libcoreinst::install[][src]

Functions

To be used with visit_bls_entry_options(). Modifies the BLS config as instructed by delete_args and append_args.

Calls a function on the latest (default) BLS entry and optionally updates it if the function returns new content. Errors out if no BLS entry was found.

Wrapper around visit_bls_entry to specifically visit just the BLS entry’s options line and optionally update it if the function returns new content. Errors out if none or more than one options field was found.