pub struct Initrd { /* fields omitted */ }
Generate an xz-compressed initrd.
Read an initrd containing compressed and/or uncompressed archives.
Read an initrd containing compressed and/or uncompressed archives,
ignoring paths not matching the specified glob patterns.
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,