Macro libcoreinst::runcmd_output
source · macro_rules! runcmd_output { ($cmd:expr) => { ... }; ($cmd:expr, $($args:expr),*) => { ... }; }
Runs the provided command, captures its stdout, and swallows its stderr except on failure.
The first macro argument is the executable, and following arguments are passed to the command.
Returns a Result