Module libcoreinst::blockdev[][src]

Structs

Device nodes for partitionable kernel devices, managed by the kernel.

Device nodes for non-partitionable kernel devices, managed by running kpartx to parse the partition table and create device-mapper devices for each partition.

Traits

A handle to the set of device nodes for individual partitions of a device. Must be held as long as the device nodes are needed; they might be removed upon drop.

Functions

Inspect a buffer from the start of a disk image and return its formatted sector size, if any can be determined.

This is basically a Rust version of: https://github.com/coreos/coreos-assembler/blob/d3c7ec094a02/src/cmd-buildextend-live#L492-L495

Get the size of a block device.

Returns filesystems with given label. If multiple filesystems with the label have the same UUID, we only return one of them.

Get the size of the GPT metadata at the start of the disk.

Get the logical sector size of a block device.

Get the sector size of the block device at a given path.

Checks if underlying device is IBM DASD disk