Module libcoreinst::blockdev [−][src]
Structs
| Disk | |
| Mount | |
| PartTableKernel | Device nodes for partitionable kernel devices, managed by the kernel. |
| PartTableKpartx | Device nodes for non-partitionable kernel devices, managed by running kpartx to parse the partition table and create device-mapper devices for each partition. |
| Partition | |
| SavedPartitions |
Traits
| PartTable | A handle to the set of device nodes for individual partitions of a device. Must be held as long as the device nodes are needed; they might be removed upon drop. |
Functions
| detect_formatted_sector_size | Inspect a buffer from the start of a disk image and return its formatted sector size, if any can be determined. |
| get_blkdev_deps | |
| get_blkdev_deps_recursing | |
| get_block_device_size | Get the size of a block device. |
| get_gpt_size | Get the size of the GPT metadata at the start of the disk. |
| get_sector_size | Get the logical sector size of a block device. |
| get_sector_size_for_path | Get the sector size of the block device at a given path. |
| is_dasd | Checks if underlying device is IBM DASD disk |
| lsblk | |
| lsblk_single | |
| udev_settle |