Struct libcoreinst::blockdev::Disk [−][src]
pub struct Disk {
pub path: String,
}Fields
path: StringImplementations
pub fn mount_partition_by_label(
&self,
label: &str,
allow_holder: bool,
flags: MsFlags
) -> Result<Mount>
Return an empty list if we have exclusive access to the device, or a list of partitions preventing us from gaining exclusive access.
Get a handle to the set of device nodes for individual partitions of the device.