[][src]Struct libcoreinst::blockdev::Disk

pub struct Disk {
    pub path: String,
}

Fields

path: String

Implementations

impl Disk[src]

pub fn new(path: &str) -> Self[src]

pub fn mount_partition_by_label(
    &self,
    label: &str,
    allow_holder: bool,
    flags: MsFlags
) -> Result<Mount>
[src]

pub fn get_busy_partitions(self) -> Result<Vec<Partition>>[src]

Return an empty list if we have exclusive access to the device, or a list of partitions preventing us from gaining exclusive access.

pub fn get_partition_table(&self) -> Result<Box<dyn PartTable>>[src]

Get a handle to the set of device nodes for individual partitions of the device.