pub struct PartTableKpartx { /* fields omitted */ }Expand description
Device nodes for non-partitionable kernel devices, managed by running
kpartx to parse the partition table and create device-mapper devices for
each partition.
Formats the value using the given formatter. Read more
If we created the partition devices (rather than finding them
already existing), delete them afterward so we don’t leave DM
devices attached to the specified disk.
Update device nodes for the current state of the partition table
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,