Struct libcoreinst::blockdev::SavedPartitions [−][src]
pub struct SavedPartitions { /* fields omitted */ }Implementations
Create a SavedPartitions for a block device with a sector size.
Unconditionally write the saved partitions, and only the saved partitions, to the disk. Write a protective MBR and overwrite any MBR boot code. Updating the kernel partition table is the caller’s responsibility.
If any partitions are saved, merge them into the GPT from source, which must be valid, and write a protective MBR with the correct protective partition size. Updating the kernel partition table is the caller’s responsibility.
Get the sector size in use for this partition table.
Get the byte offset of the first byte not to be overwritten, if any, plus a description of the partition at that offset.