Struct libcoreinst::blockdev::SavedPartitions [−][src]
pub struct SavedPartitions { /* fields omitted */ }Implementations
impl SavedPartitions[src]
impl SavedPartitions[src]pub fn new_from_disk(
disk: &mut File,
filters: &[PartitionFilter]
) -> Result<Self>[src]
pub fn new_from_disk(
disk: &mut File,
filters: &[PartitionFilter]
) -> Result<Self>[src]Create a SavedPartitions for a block device with a sector size.
pub fn overwrite(&self, disk: &mut File) -> Result<()>[src]
pub fn overwrite(&self, disk: &mut File) -> Result<()>[src]Unconditionally write the saved partitions, and only the saved partitions, to the disk. Write a protective MBR and overwrite any MBR boot code. Updating the kernel partition table is the caller’s responsibility.
pub fn merge(
&self,
source: &mut impl Read + Seek,
disk: &mut File
) -> Result<()>[src]
pub fn merge(
&self,
source: &mut impl Read + Seek,
disk: &mut File
) -> Result<()>[src]If any partitions are saved, merge them into the GPT from source, which must be valid, and write a protective MBR with the correct protective partition size. Updating the kernel partition table is the caller’s responsibility.
pub fn get_sector_size(&self) -> u64[src]
pub fn get_sector_size(&self) -> u64[src]Get the sector size in use for this partition table.
pub fn get_offset(&self) -> Result<Option<(u64, String)>>[src]
pub fn get_offset(&self) -> Result<Option<(u64, String)>>[src]Get the byte offset of the first byte not to be overwritten, if any, plus a description of the partition at that offset.
pub fn is_saved(&self) -> bool[src]