[−][src]Struct libcoreinst::blockdev::SavedPartitions
Implementations
impl SavedPartitions[src]
pub fn new_from_disk(
disk: &mut File,
filters: &[PartitionFilter]
) -> Result<Self>[src]
disk: &mut File,
filters: &[PartitionFilter]
) -> Result<Self>
Create a SavedPartitions for a block device with a sector size.
pub fn overwrite(&self, disk: &mut File) -> Result<()>[src]
Unconditionally write the saved partitions, and only the saved partitions, to the disk. Updating the kernel partition table is the caller's responsibility.
pub fn merge(
&self,
source: &mut impl Read + Seek,
disk: &mut File
) -> Result<()>[src]
&self,
source: &mut impl Read + Seek,
disk: &mut File
) -> Result<()>
If any partitions are saved, merge them into the GPT from source, which must be valid. Updating the kernel partition table is the caller's responsibility.
pub fn get_offset(&self) -> Result<Option<(u64, String)>>[src]
Get the byte offset of the first byte not to be overwritten, if any, plus a description of the partition at that offset.
pub fn is_saved(&self) -> bool[src]