Trait libcoreinst::blockdev::PartTable[][src]

pub trait PartTable {
    fn reread(&mut self) -> Result<()>;
}
A handle to the set of device nodes for individual partitions of a device. Must be held as long as the device nodes are needed; they might be removed upon drop.

Required methods

fn reread(&mut self) -> Result<()>[src]

Update device nodes for the current state of the partition table

Loading content...

Implementors

Loading content...