Struct libcoreinst::cmdline::CommonCustomizeConfig [−][src]
pub struct CommonCustomizeConfig {
pub dest_ignition: Vec<String>,
pub dest_device: Option<String>,
pub dest_karg_append: Vec<String>,
pub dest_karg_delete: Vec<String>,
pub network_keyfile: Vec<String>,
pub ignition_ca: Vec<String>,
pub pre_install: Vec<String>,
pub post_install: Vec<String>,
pub installer_config: Vec<String>,
pub live_ignition: Vec<String>,
}Fields
dest_ignition: Vec<String>Ignition config fragment for dest sys
Automatically run installer and merge the specified Ignition config into the config for the destination system.
dest_device: Option<String>Install destination device
Automatically run installer, installing to the specified destination device. The resulting boot media will overwrite the destination device without confirmation.
dest_karg_append: Vec<String>Destination kernel argument to append
Automatically run installer, adding the specified kernel argument for every boot of the destination system.
dest_karg_delete: Vec<String>Destination kernel argument to delete
Automatically run installer, deleting the specified kernel argument for every boot of the destination system.
network_keyfile: Vec<String>NetworkManager keyfile for live & dest
Configure networking using the specified NetworkManager keyfile. Network settings will be applied in the live environment, including when Ignition is run. If installer is enabled via additional options, network settings will also be applied in the destination system, including when Ignition is run.
ignition_ca: Vec<String>Ignition PEM CA bundle for live & dest
Specify additional TLS certificate authorities to be trusted by Ignition, in PEM format. Authorities will be trusted by Ignition in the live environment and, if installer is enabled via additional options, in the destination system.
pre_install: Vec<String>Script to run before installation
If installer is run at boot, run this script before installation. If the script fails, the live environment will stop at an emergency shell.
post_install: Vec<String>Script to run after installation
If installer is run at boot, run this script after installation. If the script fails, the live environment will stop at an emergency shell.
installer_config: Vec<String>Installer config file
Automatically run coreos-installer and apply the specified installer config file. Config files are applied in the order that they are specified.
live_ignition: Vec<String>Ignition config fragment for live env
Merge the specified Ignition config into the config for the live environment.