Struct libcoreinst::cmdline::InstallConfig [−][src]
pub struct InstallConfig {Show 23 fields
pub config_file: Vec<String>,
pub stream: Option<String>,
pub image_url: Option<Url>,
pub image_file: Option<String>,
pub ignition_file: Option<String>,
pub ignition_url: Option<Url>,
pub ignition_hash: Option<IgnitionHash>,
pub architecture: DefaultedString<Architecture>,
pub platform: Option<String>,
pub firstboot_args: Option<String>,
pub append_karg: Vec<String>,
pub delete_karg: Vec<String>,
pub copy_network: bool,
pub network_dir: DefaultedString<NetworkDir>,
pub save_partlabel: Vec<String>,
pub save_partindex: Vec<String>,
pub offline: bool,
pub insecure: bool,
pub insecure_ignition: bool,
pub stream_base_url: Option<Url>,
pub preserve_on_error: bool,
pub fetch_retries: FetchRetries,
pub dest_device: Option<String>,
}Fields
config_file: Vec<String>YAML config file with install options
Load additional config options from the specified YAML config file. Later config files override earlier ones, and command-line options override config files.
Config file keys are long option names without the leading “–”. Values are strings for non-repeatable options, arrays of strings for repeatable options, and “true” for flags. The destination device can be specified with the “dest-device” key.
stream: Option<String>Fedora CoreOS stream
The name of the Fedora CoreOS stream to install, such as “stable”, “testing”, or “next”.
image_url: Option<Url>Manually specify the image URL
image_file: Option<String>Manually specify a local image file
ignition_file: Option<String>Embed an Ignition config from a file
ignition_url: Option<Url>Embed an Ignition config from a URL
Immediately fetch the Ignition config from the URL and embed it in the installed system.
ignition_hash: Option<IgnitionHash>Digest (type-value) of the Ignition config
Verify that the Ignition config matches the specified digest,
formatted as
architecture: DefaultedString<Architecture>Target CPU architecture
Create an install disk for a different CPU architecture than the host.
platform: Option<String>Override the Ignition platform ID
Install a system that will run on the specified cloud or virtualization platform, such as “vmware”.
firstboot_args: Option<String>Additional kernel args for the first boot
append_karg: Vec<String>Append default kernel arg
Add a kernel argument to the installed system.
delete_karg: Vec<String>Delete default kernel arg
Delete a default kernel argument from the installed system.
copy_network: boolCopy network config from install environment
Copy NetworkManager keyfiles from the install environment to the installed system.
network_dir: DefaultedString<NetworkDir>For use with -n
Specify the path to NetworkManager keyfiles to be copied with –copy-network.
save_partlabel: Vec<String>Save partitions with this label glob
save_partindex: Vec<String>Save partitions with this number or range
offline: boolForce offline installation
insecure: boolSkip signature verification
insecure_ignition: boolAllow Ignition URL without HTTPS or hash
stream_base_url: Option<Url>Base URL for CoreOS stream metadata
Override the base URL for fetching CoreOS stream metadata. The default is “https://builds.coreos.fedoraproject.org/streams/”.
preserve_on_error: boolDon’t clear partition table on error
If installation fails, coreos-installer normally clears the destination’s partition table to prevent booting from invalid boot media. Skip clearing the partition table as a debugging aid.
fetch_retries: FetchRetriesFetch retries, or “infinite”
Number of times to retry network fetches, or the string “infinite” to retry indefinitely.
dest_device: Option<String>Destination device
Path to the device node for the destination disk. The beginning of the device will be overwritten without further confirmation.
Implementations