pub struct InstallConfig {Show 13 fields
pub device: String,
pub location: Box<dyn ImageLocation>,
pub ignition: Option<File>,
pub ignition_hash: Option<IgnitionHash>,
pub platform: Option<String>,
pub firstboot_kargs: Option<String>,
pub append_kargs: Vec<String>,
pub delete_kargs: Vec<String>,
pub insecure: bool,
pub preserve_on_error: bool,
pub network_config: Option<String>,
pub save_partitions: Vec<PartitionFilter>,
pub fetch_retries: FetchRetries,
}impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,