Struct libcoreinst::cmdline::IsoCustomizeConfig
source · [−]pub struct IsoCustomizeConfig {
pub common: CommonCustomizeConfig,
pub live_karg_append: Vec<String>,
pub live_karg_delete: Vec<String>,
pub live_karg_replace: Vec<String>,
pub force: bool,
pub output: Option<String>,
pub input: String,
}Fields
common: CommonCustomizeConfiglive_karg_append: Vec<String>Live kernel argument to append
Kernel argument to append to boots of the live environment.
live_karg_delete: Vec<String>Live kernel argument to delete
Kernel argument to delete from boots of the live environment.
live_karg_replace: Vec<String>Live kernel argument to replace
Kernel argument to replace for boots of the live environment, in the form key=old=new. For a default argument “a=b”, specifying “–live-karg-replace a=b=c” will produce the argument “a=c”.
force: boolOverwrite existing customizations
output: Option<String>Write ISO to a new output file
input: StringISO image